@@ -4,5 +4,8 @@ use strict;
 use base qw[
   JavaScript::MochiKit::Accessor
 ];
+use vars qw [ @Dependencies ];
+
+@Dependencies = qw [ Base ];
 
 1;
